@@ -1,4 +1,4 @@
-from typing import Generator, Tuple, List
+from typing import Generator, Tuple, Sequence
 
 from pydmt.api.builder import Builder, SourceFile, TargetFile, Node
 from pydmt.utils.digest import sha1_file
@@ -13,13 +13,13 @@ class OneSourceOneTarget(Builder):
         super().__init__()
         self.source = source
         self.target = target
-        self.sources = [SourceFile(filename=source)]
-        self.targets = [TargetFile(filename=target)]
+        self.sources: Sequence[Node] = [SourceFile(filename=source)]
+        self.targets: Sequence[Node] = [TargetFile(filename=target)]
 
-    def get_sources(self) -> List[Node]:
+    def get_sources(self) -> Sequence[Node]:
         return self.sources
 
-    def get_targets(self) -> List[Node]:
+    def get_targets(self) -> Sequence[Node]:
         return self.targets
 
     def yield_results(self) -> Generator[Tuple[str, str], None, None]:
