@@ -1,19 +1,14 @@
 from pydmt.api.feature import Feature
 from pydmt.builders.apt import BuilderApt
 from pydmt.core.pydmt import PyDMT
+from pydmt.helpers.urls import get_deps
 
 
 class FeatureApt(Feature):
     def __init__(
         self,
     ):
-        self.packages = None
-        # pylint: disable=import-outside-toplevel
-        try:
-            import config.deps
-            self.packages = config.deps.packages
-        except ModuleNotFoundError:
-            pass
+        self.packages = get_deps()
 
     def setup(self, pydmt: PyDMT) -> None:
         if self.packages is not None:
